@@ -1,6 +1,6 @@
 __author__ = "Sam Nicholls <sn8@sanger.ac.uk>"
 __copyright__ = "Copyright (c) Sam Nicholls"
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __maintainer__ = "Sam Nicholls <sam@samnicholls.net>"
 
 class AbstractReader(object):
@@ -30,6 +30,10 @@ class AbstractReader(object):
         #TODO Check file is not already closed...
         self.handler.close()
 
+    def get_id(self):
+        """Return record ID."""
+        raise NotImplementedError("get_id has not been implemented")
+
     def get_data(self):
         """Return read data."""
         raise NotImplementedError("get_data has not been implemented")
