@@ -1,6 +1,6 @@
 __author__ = "Sam Nicholls <sn8@sanger.ac.uk>"
 __copyright__ = "Copyright (c) Sam Nicholls"
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __maintainer__ = "Sam Nicholls <sam@samnicholls.net>"
 
 import numpy as np
@@ -81,8 +81,9 @@ class Statplexer(object):
             for f in files:
                 fpath = os.path.join(root, f)
 
-                _data = DATA_READER_CLASS(fpath, self._classes, auto_close=True).get_data()
-                _id = _data["_id"]
+                drc = DATA_READER_CLASS(fpath, self._classes, auto_close=True)
+                _data = drc.get_data()
+                _id = drc.get_id()
 
                 if _id in self._data:
                     print("[WARN] Duplicate observation %s found in %s" % (_id, fpath))
