@@ -1,6 +1,6 @@
 __author__ = "Sam Nicholls <sn8@sanger.ac.uk>"
 __copyright__ = "Copyright (c) Sam Nicholls"
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __maintainer__ = "Sam Nicholls <sam@samnicholls.net>"
 
 import unittest
@@ -28,7 +28,7 @@ class TestBamcheckReader(unittest.TestCase):
         example_lines = open(DATA_PATH).readlines()
         bamcheck = bcr.BamcheckReader(DATA_PATH)
 
-        SN_count = 1 # Include _id
+        SN_count = 0
         for line in example_lines:
             if line.startswith("SN"):
                 SN_count += 1
@@ -38,7 +38,7 @@ class TestBamcheckReader(unittest.TestCase):
         example_lines = open(DUP_DATA_PATH).readlines()
         dup_bamcheck = bcr.BamcheckReader(DUP_DATA_PATH)
 
-        SN_count = 1 # Include _id
+        SN_count = 0
         keys = []
         for line in example_lines:
             if line.startswith("SN"):
@@ -83,7 +83,7 @@ class TestBamcheckReader(unittest.TestCase):
     def test_id_key(self):
         example_lines = open(DATA_PATH).readlines()
         bamcheck = bcr.BamcheckReader(DATA_PATH)
-        self.assertEqual(os.path.basename(DATA_PATH).split(".")[0], bamcheck.get_data()["_id"])
+        self.assertEqual(os.path.basename(DATA_PATH).split(".")[0], bamcheck.get_id())
 
 
 if __name__ == '__main__':
